package com.caimei365.user.service.impl;

import com.aliyun.oss.internal.OSSUtils;
import com.aliyuncs.exceptions.ClientException;
import com.caimei365.user.components.CommonService;
import com.caimei365.user.components.RedisService;
import com.caimei365.user.mapper.BaseMapper;
import com.caimei365.user.mapper.LoginMapper;
import com.caimei365.user.mapper.SuperVipMapper;
import com.caimei365.user.mapper.UserCenterMapper;
import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.MobileDto;
import com.caimei365.user.model.dto.PasswordDto;
import com.caimei365.user.model.dto.SuperVipDto;
import com.caimei365.user.model.po.SuperVipPo;
import com.caimei365.user.model.po.VipPackage;
import com.caimei365.user.model.po.VipPayHistoryPo;
import com.caimei365.user.model.vo.CouponVo;
import com.caimei365.user.model.vo.UserLoginVo;
import com.caimei365.user.service.BaseService;
import com.caimei365.user.service.RemoteCallService;
import com.caimei365.user.utils.*;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.util.ObjectUtils;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.*;


/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/4
 */
@Slf4j
@Service
public class BaseServiceImpl implements BaseService {
    @Resource
    private SuperVipMapper vipMapper;
    @Resource
    private CommonService commonService;
    @Resource
    private RedisService redisService;
    @Resource
    private BaseMapper baseMapper;
    @Resource
    private LoginMapper loginMapper;
    @Value("${spring.cloud.config.profile}")
    private String profile;
    @Resource
    private RemoteCallService remoteCallService;
    @Resource
    private UserCenterMapper userCenterMapper;

    /**
     * 获取图片验证码
     *
     * @param platformType 0:www，1:crm/h5，2:小程序
     */
    @Override
    public ResponseJson<Map<String, Object>> getCaptchaImage(Integer platformType) {
        log.info(profile);
        Map<String, Object> result = new HashMap<>(2);
        try {
            ImageCaptchaUtil.Captcha captcha = null;
            String captchaKey = "";
            while (StringUtils.isBlank(captchaKey)) {
                captcha = ImageCaptchaUtil.getCaptcha(200, 80, 4);
                captchaKey = ImageCaptchaUtil.getCaptchaKey(captcha.getMd5Code(), platformType);
                boolean exists = redisService.exists(captchaKey);
                // 为了防止重复的图片验证码, 存在就循环重新生成
                if (!exists) {
                    // 保存5分钟
                    redisService.set(captchaKey, captcha.getCode(), 5 * 60L);
                    break;
                }
            }
            result.put("baseImage", captcha.getBase64Image());
            result.put("token", captcha.getMd5Code());
            log.info("获取图片验证码:" + captcha.getCode() + ",token:" + captcha.getMd5Code());
            return ResponseJson.success(result);
        } catch (Exception e) {
            log.info(e.getMessage());
            return ResponseJson.error("获取图片验证码异常", null);
        }
    }

    /**
     * 校验图片验证码
     *
     * @param token        图片验证码token
     * @param imgCode      图片验证码
     * @param platformType 0:www，1:crm/h5，2:小程序
     * @return Boolean
     */
    @Override
    public Boolean checkCaptchaImage(String token, String imgCode, Integer platformType) {
        if (StringUtils.isBlank(token) || StringUtils.isBlank(imgCode)) {
            return false;
        }
        String captchaKey = ImageCaptchaUtil.getCaptchaKey(token, platformType);
        String captchaCode = (String) redisService.get(captchaKey);
        if (StringUtils.isNotEmpty(captchaCode) && StringUtils.equalsIgnoreCase(imgCode, captchaCode)) {
            // 校验成功
            return true;
        }
        // 不管验证是否成功删除旧的图片验证码
        redisService.remove(captchaKey);
        return false;
    }

    /**
     * 获取短信验证码
     *
     * @param mobile           手机号
     * @param activateCodeType 1:找回密码,2:手机号注册机构,3:供应商注册,4:修改手机号-旧手机验证码,5:修改手机号-新手机验证码,7:手机验证码登录,8:联合丽格注册,9:联合丽格登录验证,10:联合丽格找回密码,11:联合丽格更换手机号--旧手机验证码,12:联合丽格更换手机号--新手机验证码,13联合丽格采购员登录
     * @param platformType     0:www，1:crm/h5，2:小程序
     * @param isCheckCaptcha   是否检查图片验证码，0:检查，1:不检查
     * @param imgCode          图片验证码
     * @param token            图片验证码token
     */
    @Override
    public ResponseJson getSmsCode(String mobile, Integer activateCodeType, Integer platformType, Integer isCheckCaptcha, String imgCode, String token) {
        // 验证手机号
        String result = ValidateUtil.validateMobile(mobile);
        if (result != null) {
            return ResponseJson.error(result);
        }
        // 检查图片验证码
        if (null == isCheckCaptcha || 0 == isCheckCaptcha) {
            Boolean checkFlag = checkCaptchaImage(token, imgCode, platformType);
            if (!checkFlag) {
                return ResponseJson.error("图形验证码错误");
            }
        }
        boolean sendFlag = false;
        // 生成六位验证码
        String randomCode = CodeUtil.generateCodeInt(6);
        boolean isBeta = "dev".equals(profile) || "beta".equals(profile);
        if (isBeta) {
            // 开发 和 测试环境 固定短信验证码 666666
            randomCode = "666666";
        }
        String codeTypeTxt = "";
        // 根据手机号查询用户Id
        Integer userId = baseMapper.getUserIdByMobile(mobile);
        if (1 == activateCodeType) {
            if (null == userId || userId < 1) {
                return ResponseJson.error("该手机号尚未注册");
            }
            // 找回密码
            String content = "验证码" + randomCode + "，您正在尝试修改登录密码，请妥善保管账户信息。";
            sendFlag = isBeta || remoteCallService.remoteSendSms(0, 1, mobile, content);
            codeTypeTxt = "找回密码";
        } else if (2 == activateCodeType || 3 == activateCodeType) {
            if (null != userId && userId > 0) {
                return ResponseJson.error("该手机号已被使用");
            }
            if (2 == activateCodeType) {
                // 机构用户(自主)注册
                String content = "欢迎注册采美365网，您的短信验证码为：" + randomCode + "，该验证码 5 分钟内有效，请勿泄漏于他人。";
                sendFlag = isBeta || remoteCallService.remoteSendSms(0, 1, mobile, content);
                codeTypeTxt = "机构(自主)注册";
            } else if (3 == activateCodeType) {
                // 供应商(自主)注册
                String content = "欢迎注册采美365网供应商账号，您的短信验证码为：" + randomCode + "，该验证码 5 分钟内有效，请勿泄漏于他人。";
                sendFlag = isBeta || remoteCallService.remoteSendSms(0, 1, mobile, content);
                codeTypeTxt = "供应商(自主)注册";
            } else {
                return ResponseJson.error("参数错误：activateCodeType");
            }
        } else if (4 == activateCodeType) {
            // 您正在更换联系人手机号，您的验证码为：${code}。
            String content = "验证码" + randomCode + "，您正在尝试变更重要信息，请妥善保管账户信息。";
            sendFlag = isBeta || remoteCallService.remoteSendSms(0, 1, mobile, content);
            codeTypeTxt = "更换联系人(旧手机号验证码)";
        } else if (5 == activateCodeType) {
            if (null != userId && userId > 0) {
                return ResponseJson.error("该手机号已被使用");
            }
            // 您正在更换联系人手机号，您的验证码为：${code}。
            String content = "验证码" + randomCode + "，您正在尝试变更重要信息，请妥善保管账户信息。";
            sendFlag = isBeta || remoteCallService.remoteSendSms(0, 1, mobile, content);
            codeTypeTxt = "更换联系人(新手机号验证码)";
        } else if (6 == activateCodeType) {
            String content = "您正在采美平台发布二手商品，您的验证码为：" + randomCode + "，10分钟内有效，请勿泄露他人。";
            sendFlag = isBeta || remoteCallService.remoteSendSms(0, 1, mobile, content);
            codeTypeTxt = "更换联系人(旧手机号验证码)";
        } else if (7 == activateCodeType || 9 == activateCodeType) {
            // 校验是否发送验证码
            /*Object resCode = redisService.get("code:" + mobile);
            long expireTime = redisService.getExpireTime("code:" + mobile);
            if (!ObjectUtils.isEmpty(resCode) || expireTime >= 0) {
                return ResponseJson.error("验证码已发送，请勿重复操作");
            }*/
            // 重复发送，删除前一个验证码
            redisService.remove("code:"+ mobile);
            Integer dbUserId = null;
            // 根据手机号查询用户Id
            String content = "";
            if (7 == activateCodeType) {
                // 采美系统登陆发送短信
                dbUserId = baseMapper.getUserIdByMobile(mobile);
                if (dbUserId == null) {
                    return ResponseJson.error("该手机号暂未注册");
                }
                // 您正在操作登录采美商城，验证码：{s6}，请在5分钟内完成验证。如非本人操作，请忽略本短信。
                content = "您正在操作登录采美商城，验证码：" + randomCode + "，请在5分钟内完成验证。如非本人操作，请忽略本短信。";
                codeTypeTxt = "登录采美商城";
            } else if (9 == activateCodeType){
                // 联合丽格登录发送短信
                dbUserId = baseMapper.getUserIdByOrganize(4,mobile);
                if (dbUserId == null) {
                    return ResponseJson.error("该手机号暂未注册");
                }
                UserLoginVo userLoginVo = baseMapper.getUserIdByOrganizeStatus(4, mobile);
                if ( null != userLoginVo.getClubStatus()) {
                    if (1 == userLoginVo.getClubStatus()) {
                        return ResponseJson.error(-1, "账号待审核，请耐心等待审核结果", null);
                    }
                    if (91 == userLoginVo.getClubStatus()) {
                        return ResponseJson.error(-1, "该手机号已下线", null);
                    }
                }
                if (1 == userLoginVo.getUserIdentity()) {
                    return ResponseJson.error(-1, "该手机号，暂未注册成为机构用户", null);
                }
                // 欢迎登录联合丽格，您的验证码为：{s6}，5分钟内有效，请勿泄漏他人。
                content = "【丽格集采联盟】欢迎登录联合丽格，您的验证码为：" + randomCode + "，5分钟内有效，请勿泄漏他人。";
                codeTypeTxt = "登录联合丽格";
            } else {
                return ResponseJson.error("参数错误：activateCodeType");
            }
            boolean smsFlag = isBeta || remoteCallService.remoteSendSms(0,1,mobile,content);
            if (!smsFlag) {
                // 短信发送失败重试一次
                smsFlag = remoteCallService.remoteSendSms(0,1,mobile,content);
            }
            if (smsFlag) {
                redisService.set("code:"+ mobile, randomCode,300L);
                log.info(codeTypeTxt + "登录短信，发送到"+ mobile + "的验证码为："+ randomCode);
                return ResponseJson.success("发送验证码成功");
            } else {
                log.info(codeTypeTxt + ",验证码发送失败！");
                return ResponseJson.error("发送验证码失败，请稍后再试");
            }
        } else if (8 == activateCodeType) {
            // 联合丽格注册发送短信
            Integer dbUserId = baseMapper.getUserIdByOrganize(4,mobile);
            if (dbUserId != null) {
                return ResponseJson.error("该手机号已注册");
            }
            // 您的验证码为：{s6}，5分钟内有效，请勿泄漏他人。
            String content = "【丽格集采联盟】您的验证码为：" + randomCode + "，5分钟内有效，请勿泄漏他人。";
            sendFlag = isBeta || remoteCallService.remoteSendSms(0,1,mobile,content);
            if (!sendFlag) {
                // 短信发送失败重试一次
                sendFlag = remoteCallService.remoteSendSms(0,1,mobile,content);
            }
            codeTypeTxt = "联合丽格注册";
        } else if (10 == activateCodeType){
            // 联合丽格找回密码发送短信
            Integer dbUserId = baseMapper.getUserIdByOrganize(4,mobile);
            if (dbUserId == null) {
                return ResponseJson.error("该手机号暂未注册");
            }
            // 您正在修改密码，验证码为：{s6}，5分钟内有效，请勿泄漏他人。
            String content = "【丽格集采联盟】您正在修改密码，验证码为：" + randomCode + "，5分钟内有效，请勿泄漏他人。";
            sendFlag = isBeta || remoteCallService.remoteSendSms(0,1,mobile,content);
            if (!sendFlag) {
                // 短信发送失败重试一次
                sendFlag = remoteCallService.remoteSendSms(0,1,mobile,content);
            }
            codeTypeTxt = "联合丽格找回密码";
        } else if (11 == activateCodeType){
                // 联合丽格
                // 您正在更改手机号，验证码为：{s6}，5分钟内有效，请勿泄漏他人。
                String content = "【丽格集采联盟】您正在更改手机号，验证码为：" + randomCode + "，5分钟内有效，请勿泄漏他人。";

                sendFlag = isBeta || remoteCallService.remoteSendSms(0, 1, mobile, content);
                codeTypeTxt = "更换联系人(旧手机号验证码)";
        } else if (12 == activateCodeType) {
            // 联合丽格
            if (null != userId && userId > 0) {
                return ResponseJson.error("该手机号已被使用");
            }
            // 您正在更改手机号，验证码为：{s6}，5分钟内有效，请勿泄漏他人。
            String content = "【丽格集采联盟】您正在更改手机号，验证码为：" + randomCode + "，5分钟内有效，请勿泄漏他人。";
            sendFlag = isBeta || remoteCallService.remoteSendSms(0, 1, mobile, content);
            codeTypeTxt = "更换联系人(新手机号验证码)";
        } else if (13 == activateCodeType) {
            UserLoginVo loginVo = baseMapper.getServiceProvider(mobile);
            if (null == loginVo) {
                return ResponseJson.error(-1, "该手机号暂未添加为采购员", null);
            }
            if (90 != loginVo.getOperationStatus()) {
                return ResponseJson.error(-1, "该采购员账号已下线", null);
            }
            // 【丽格集采联盟】您的验证码为：{s6}，5分钟内有效，请勿泄漏他人。
            String content = "【丽格集采联盟】您的验证码为：" + randomCode + "，5分钟内有效，请勿泄漏他人。";
            sendFlag = isBeta || remoteCallService.remoteSendSms(0,1,mobile,content);
            if (!sendFlag) {
                // 短信发送失败重试一次
                sendFlag = remoteCallService.remoteSendSms(0,1,mobile,content);
            }
            codeTypeTxt = "联合丽格采购员登录";
        } else {
            return ResponseJson.error("参数错误：activateCodeType");
        }
        if (sendFlag) {
            if (6 == activateCodeType) {
                //二手验证码10分钟有效期
                redisService.set("code:" + mobile, randomCode, 600L);
            } else if (8 == activateCodeType || 10 == activateCodeType || 11 == activateCodeType) {
                // 联合丽格验证码5分钟有效期
                redisService.set("code:" + mobile, randomCode, 300L);
            }else {
                redisService.set("code:" + mobile, randomCode, 1800L);
            }
            log.info(codeTypeTxt + ",发送到:" + mobile + "的短信验证码为: " + randomCode);
        } else {
            log.info(codeTypeTxt + ",验证码发送失败！");
            return ResponseJson.error("验证码发送失败！请稍后重试");
        }
        return ResponseJson.success("发送验证码成功");
    }

    /**
     * 绑定账号,发送短信验证
     *
     * @param mobile         运营人员手机号
     * @param bindMobile     机构手机号
     * @param platformType   0:www，1:crm/h5，2:小程序
     * @param isCheckCaptcha 是否检查图片验证码，0:检查，1:不检查
     * @param imgCode        图片验证码
     * @param token          图片验证码token
     */
    @Override
    public ResponseJson getBindSmsCode(String mobile, String bindMobile, Integer userId, Integer platformType, Integer isCheckCaptcha, String imgCode, String token) {
        // 验证手机号
        String result = ValidateUtil.validateMobile(mobile);
        if (result != null) {
            return ResponseJson.error(result);
        }
        // 检查图片验证码
        if (null == isCheckCaptcha || 0 == isCheckCaptcha) {
            Boolean checkFlag = checkCaptchaImage(token, imgCode, platformType);
            if (!checkFlag) {
                return ResponseJson.error("图片验证码错误");
            }
        }
        Integer dbUserId = null;
        if (StringUtils.isNotBlank(bindMobile)) {
            result = ValidateUtil.validateMobile(bindMobile);
            if (result != null) {
                return ResponseJson.error(result);
            }
            // 根据手机号查询用户Id
            dbUserId = baseMapper.getUserIdByMobile(bindMobile);
        } else if (null != userId) {
            // 根据用户Id查询用户是否存在
            dbUserId = baseMapper.getUserIdByUserId(userId);
        }
        if (null == dbUserId) {
            return ResponseJson.error("你输入的账号不存在");
        }
        Integer operationUserId = baseMapper.getOperationUserIdByMobile(mobile);
        if (null != operationUserId) {
            // 判断运营人员是否是机构手机号
            Integer tempId = baseMapper.getUserIdByMobile(mobile);
            if (null != tempId && tempId.equals(userId)) {
                // 判断机构状态
                Integer clubStatus = baseMapper.getClubStatusByUserId(operationUserId);
                if (null != clubStatus && 91 != clubStatus) {
                    return ResponseJson.error("该手机号已被机构使用");
                }
                // 判断供应商状态
                Integer shopStatus = baseMapper.getShopStatusByUserId(operationUserId);
                if (null != shopStatus && 91 != shopStatus) {
                    return ResponseJson.error("该手机号已被供应商使用");
                }
            }
        }
        // 生成六位验证码
        String randomCode = CodeUtil.generateCodeInt(6);
        boolean isBeta = "dev".equals(profile) || "beta".equals(profile);
        if (isBeta) {
            // 开发 和 测试环境 固定短信验证码 666666
            randomCode = "666666";
        }
        //	欢迎成为机构运营人员，您的验证码为{s6}。运营人员可通过微信授权直接登录采美365网。
        String content = "欢迎成为机构运营人员运营人员，您的验证码为" + randomCode + "。运营人员可通过微信授权直接登录采美365网。";
        boolean smsFlag = isBeta || remoteCallService.remoteSendSms(0, 1, mobile, content);
        if (!smsFlag) {
            // 短信发送失败重试一次
            smsFlag = remoteCallService.remoteSendSms(0, 1, mobile, content);
        }
        if (smsFlag) {
            redisService.set("code:" + mobile, randomCode, 1800L);
            log.info("绑定账号,发送到:" + mobile + "的短信验证码为: " + randomCode);
            return ResponseJson.success("发送验证码成功");
        } else {
            return ResponseJson.error("验证码发送失败！请稍后重试");
        }
    }

    /**
     * 获取邮箱验证码
     *
     * @param email  邮箱
     * @param status 1:绑定邮箱,2邮箱注册,3邮箱找回秘密
     */
    @Override
    public ResponseJson getEmailCode(String email, Integer status) {
        // 验证邮箱
        if (!ValidateUtil.validateEmail(email)) {
            return ResponseJson.error("邮箱格式不正确");
        }
        Integer dbUserId = baseMapper.getUserIdByEmail(email);
        try {
            // 生成六位验证码
            String randomCode = CodeUtil.generateCodeInt(6);
            boolean isBeta = "dev".equals(profile) || "beta".equals(profile);
            if (isBeta) {
                // 开发 和 测试环境 固定短信验证码 666666
                randomCode = "666666";
            }
            String html = EmailUtil.setMailCode(status, randomCode);
            String subject = "";
            // status 1:绑定邮箱,2邮箱注册,3邮箱找回秘密
            if (status == 1) {
                if (dbUserId != null) {
                    return ResponseJson.error("该邮箱已被使用");
                }
                subject = "采美365网邮箱绑定验证邮件";
            } else if (status == 2) {
                if (dbUserId != null) {
                    return ResponseJson.error("该邮箱已被使用");
                }
                subject = "采美365网注册验证邮件";
            } else if (status == 3) {
                if (dbUserId == null) {
                    return ResponseJson.error("该邮箱尚未注册");
                }
                subject = "采美365网修改密码验证邮件";
            }
            EmailUtil.sendMail(email, subject, html);
            redisService.set("code:" + email, randomCode, 1800L);
            log.info("subject,发送到:" + email + "的验证码为: " + randomCode);
        } catch (Exception e) {
            return ResponseJson.error("发送验证码失败");
        }
        return ResponseJson.success("发送验证码成功", "");
    }

    /**
     * 获取登录验证码
     *
     * @param mobile 输入手机号
     * @return
     */
    @Override
    public ResponseJson getLoginCode(String mobile) {

        // 验证手机号
        String result = ValidateUtil.validateMobile(mobile);
        if (result != null) {
            return ResponseJson.error(result);
        }

        Integer dbUserId = null;
        // 根据手机号查询用户Id
        dbUserId = baseMapper.getUserIdByMobile(mobile);
        if (dbUserId == null) {
            return ResponseJson.error("该手机号暂未注册");
        }

        return ResponseJson.success();
    }

    /**
     * 获取绑定运营人员验证码
     *
     * @param mobile
     * @return
     */
    @Override
    public ResponseJson operateSmsCode(String mobile) {
        // 验证手机号
        String result = ValidateUtil.validateMobile(mobile);
        if (result != null) {
            return ResponseJson.error(result);
        }
        // 校验是否发送验证码
        Object resCode = redisService.get("code:" + mobile);
        long expireTime = redisService.getExpireTime("code:" + mobile);
        if (!ObjectUtils.isEmpty(resCode) || expireTime >= 0) {
            return ResponseJson.error("验证码已发送，请勿重复操作");
        }

        // 重复发送，删除前一个验证码
        /*redisService.remove("code:"+ mobile);*/
        Integer dbUserId = null;
        // 根据手机号查询用户Id
        dbUserId = baseMapper.getUserIdByMobile(mobile);
        if (dbUserId == null) {
            return ResponseJson.error("该手机号暂未注册");
        }
        // 生成6位数验证码
        String randomCode = CodeUtil.generateCodeInt(6);
        // 开发、测试环境下短信验证码固定为666666
        boolean isCode = "dev".equals(profile)||"beta".equals(profile);
        if (isCode) {
            randomCode = "666666";
        }
        // 您正在操作绑定运营人员，验证码：{s6}，请在5分钟内完成验证。如非本人操作，请忽略本短信。
        String content = "您正在操作绑定运营人员，验证码："+ randomCode+"，请在5分钟内完成验证。如非本人操作，请忽略本短信。";
        boolean smsFlag = isCode || remoteCallService.remoteSendSms(0,1,mobile,content);
        if (!smsFlag) {
            smsFlag = remoteCallService.remoteSendSms(0,1,mobile,content);
        }
        if (smsFlag) {
            redisService.set("code:"+mobile,randomCode,300L);
            log.info("绑定运营人员，发送到："+mobile+"验证码为："+randomCode);
            return ResponseJson.success("发送验证码成功");
        } else {
            return ResponseJson.error("发送验证码失败，请稍后再试");
        }
    }

    /**
     * 修改密码（找回密码）
     *
     * @param passwordDto {
     *                    mobileOrEmail 手机号或邮箱
     *                    smsCode       短信验证码(旧：activationCode)
     *                    password      密码
     *                    confirmPwd    确认密码
     *                    status        1:手机号找回,2:邮箱找回
     *                    }
     */
    @Override
    public ResponseJson updatePassword(PasswordDto passwordDto) {
        String mobileOrEmail = passwordDto.getMobileOrEmail();
        String smsCode = passwordDto.getSmsCode();
        String passWord = passwordDto.getPassword();
        String confirmPwd = passwordDto.getPasswordConfirm();
        Integer status = passwordDto.getStatus();
        if (status == 1) {
            // 验证手机号
            String result = ValidateUtil.validateMobile(mobileOrEmail);
            if (result != null) {
                return ResponseJson.error(result);
            }
        } else {
            // 验证邮箱
            if (!ValidateUtil.validateEmail(mobileOrEmail)) {
                return ResponseJson.error("邮箱格式不正确");
            }
        }
        if (StringUtils.isEmpty(smsCode)) {
            return ResponseJson.error("请输入验证码");
        }
        String redisSmsCode = (String) redisService.get("code:" + mobileOrEmail);
        // 开发 和 测试环境 固定短信验证码 666666
        if ("dev".equals(profile) || "beta".equals(profile)) {
            redisSmsCode = (null != redisSmsCode && !"null".equals(redisSmsCode) ? redisSmsCode : "666666");
        }
        if (!smsCode.equals(redisSmsCode)) {
            return ResponseJson.error("验证码错误");
        }
        // 查找用户表是否存在
        Integer dbUserId;
        if (status == 1) {
            dbUserId = baseMapper.getUserIdByMobile(mobileOrEmail);
            if (dbUserId == null) {
                return ResponseJson.error("该手机号尚未注册");
            }
        } else {
            dbUserId = baseMapper.getUserIdByEmail(mobileOrEmail);
            if (dbUserId == null) {
                return ResponseJson.error("该邮箱尚未注册");
            }
        }
        if (StringUtils.isEmpty(passWord)) {
            return ResponseJson.error("请输入新密码");
        }
        if (StringUtils.isEmpty(confirmPwd)) {
            return ResponseJson.error("请确认密码");
        }
        if (!passWord.equals(confirmPwd)) {
            return ResponseJson.error("两次输入的密码不一致");
        }
        // 设置密码
        String dbPassword = Md5Util.md5(passWord);
        baseMapper.updatePasswordByUserId(dbPassword, dbUserId);
        //重新设置密码后将登录失败表中近30分钟记录置为删除
        redisService.remove("login-"+dbUserId);
        return ResponseJson.success("密码修改成功", "");
    }

    /**
     * 修改密码（找回密码）
     *
     * @param passwordDto {
     *                    mobileOrEmail 手机号或邮箱
     *                    smsCode       短信验证码(旧：activationCode)
     *                    password      密码
     *                    confirmPwd    确认密码
     *                    status        1:手机号找回,2:邮箱找回
     *                    }
     */
    @Override
    public ResponseJson updateOrganizePassword(PasswordDto passwordDto) {
        String mobileOrEmail = passwordDto.getMobileOrEmail();
        String smsCode = passwordDto.getSmsCode();
        String passWord = passwordDto.getPassword();
        String confirmPwd = passwordDto.getPasswordConfirm();
        Integer status = passwordDto.getStatus();
        // 验证手机号
        String result = ValidateUtil.validateMobile(mobileOrEmail);
        if (result != null) {
            return ResponseJson.error(result);
        }
        if (StringUtils.isEmpty(smsCode)) {
            return ResponseJson.error("请输入验证码");
        }
        String redisSmsCode = (String) redisService.get("code:" + mobileOrEmail);
        // 开发 和 测试环境 固定短信验证码 666666
        if ("dev".equals(profile) || "beta".equals(profile)) {
            redisSmsCode = (null != redisSmsCode && !"null".equals(redisSmsCode) ? redisSmsCode : "666666");
        }
        if (!smsCode.equals(redisSmsCode)) {
            return ResponseJson.error("验证码错误");
        }
        // 查找用户表是否存在
        Integer dbUserId = baseMapper.getUserIdOrganizeByMobile(mobileOrEmail);

        if (dbUserId == null) {
            return ResponseJson.error("该手机号尚未注册");
        }

        if (StringUtils.isEmpty(passWord)) {
            return ResponseJson.error("请输入新密码");
        }
        if (StringUtils.isEmpty(confirmPwd)) {
            return ResponseJson.error("请确认密码");
        }
        if (!passWord.equals(confirmPwd)) {
            return ResponseJson.error("两次输入的密码不一致");
        }
        // 设置密码
        String dbPassword = Md5Util.md5(passWord);
        baseMapper.updatePasswordByUserId(dbPassword, dbUserId);
        //重新设置密码后将登录失败表中近30分钟记录置为删除
        redisService.remove("login-"+dbUserId);
        return ResponseJson.success("密码修改成功", "");
    }

    /**
     * 更换手机号
     *
     * @param mobileDto {
     *                  mobile          旧手机号(contractMobile)
     *                  smsCode         旧手机短信验证码(mobileCode)
     *                  newMobile       新手机号(contractMobile2)
     *                  newSmsCode      新手机短信验证码(mobileCode)
     *                  userId          用户Id
     *                  }
     */
    @Override
    public ResponseJson updateMobile(MobileDto mobileDto) {
        // 参数校验
        if (StringUtils.isBlank(mobileDto.getNewMobile())) {
            return ResponseJson.error("参数异常：新手机号不能为空！");
        }
        if (StringUtils.isBlank(mobileDto.getNewSmsCode())) {
            return ResponseJson.error("参数异常：新手机号验证码不能为空！");
        }
        if (null == mobileDto.getUserId()) {
            return ResponseJson.error("参数异常：用户Id不能为空！");
        }
        if (StringUtils.isBlank(mobileDto.getMobile())) {
            return ResponseJson.error("参数异常：旧手机号不能为空！");
        }
        if (StringUtils.isBlank(mobileDto.getSmsCode())) {
            return ResponseJson.error("参数异常：旧手机号验证码不能为空！");
        }
        // 旧手机号与验证码校验
        String result = ValidateUtil.validateMobile(mobileDto.getMobile());
        if (result != null) {
            return ResponseJson.error(result);
        }
        String smsCode = (String) redisService.get("code:" + mobileDto.getMobile());
        // 开发 和 测试环境 固定短信验证码 666666
        if ("dev".equals(profile) || "beta".equals(profile)) {
            smsCode = (null != smsCode && !"null".equals(smsCode) ? smsCode : "666666");
        }
        if (!mobileDto.getSmsCode().equals(smsCode)) {
            return ResponseJson.error("旧手机验证码错误");
        }
        UserLoginVo user = loginMapper.getLoginUserByUserId(mobileDto.getUserId());
        if (null == user) {
            return ResponseJson.error("账户异常");
        }
        //验证新手机号是否可用
        result = commonService.mobileAndCodeValidate(mobileDto.getNewMobile(), mobileDto.getNewSmsCode());
        if (result != null) {
            return ResponseJson.error(result);
        }
        // 更新user表手机号
        baseMapper.updateMobileByUserId(mobileDto.getNewMobile(), mobileDto.getUserId());
        if (user.getUserIdentity() == 3) {
            //供应商修改手机号
            baseMapper.updateShopMobileByShopId(mobileDto.getNewMobile(), user.getShopId());
        } else {
            //机构修改手机号
            baseMapper.updateClubMobileByClubId(mobileDto.getNewMobile(), user.getClubId());
        }
        return ResponseJson.success();
    }

    /**
     * 根据id查超级会员购买记录
     *
     * @param userId
     * @return
     */
    @Override
    public ResponseJson findVipHistory(Integer userId, Integer pageNum, Integer pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<VipPayHistoryPo> vipHistory = vipMapper.findVipHistory(userId);
        PageInfo<VipPayHistoryPo> historyPageInfo = new PageInfo<>(vipHistory);
        return ResponseJson.success(historyPageInfo);
    }


    @Override
    public ResponseJson<Map<String, Object>> superCenter(Integer userId, Integer source) {
        //1.封装vipDto看超级会员是否过期,0未开通，-1过期，1未过期
        SuperVipDto vipEnd = findEnd(userId);
        Map<String, Object> map = new HashMap(3);
        if (vipEnd.getVipFlag() != 0) {
            SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
            String mat = format.format(vipEnd.getEndTime());
            vipEnd.setTime(mat);
        }
        map.put("vip", vipEnd);
        //2.查当月vip优惠卷
        String nowMonth = DateUtil.getNowMonth();
        List<CouponVo> vipCoupon = vipMapper.findVipCoupon(userId, nowMonth);
        List<Integer> couponGet = vipMapper.findCouponGet(userId, nowMonth);
        List<Integer> couponUse = vipMapper.findCouponUse(userId, nowMonth);
        if (couponUse != null && couponUse.size() > 0) {
            //couponuse有就给2，没有就给1,2使用1未用
            vipCoupon.forEach(couponVo -> couponVo.setUseStatus(couponUse.contains(couponVo.getCouponId()) ? 2 : 1));
        } else {
            vipCoupon.forEach(couponVo -> couponVo.setUseStatus(1));
        }
        vipCoupon.forEach(couponVo -> couponVo.setGetFlag(couponGet.contains(couponVo.getCouponId()) ? 1 : 0));
        map.put("coupon", vipCoupon);
        return ResponseJson.success(map);
    }

    @Override
    public ResponseJson findPackage() {
        List<VipPackage> pac = vipMapper.findPackage();
        return ResponseJson.success(pac);
    }

    @Override
    public ResponseJson<HashMap<String, String>> ossTokenGet() throws ClientException {
        return ResponseJson.success(OssUtil.getToken());
    }

    /**
     * 根据userId查是否过期，返回dto对象，flag=0未买过，-1过期，1有效，endTime过期时间
     */
    private SuperVipDto findEnd(Integer userId) {
        SuperVipPo superVip = vipMapper.findSuperVip(userId);
        SuperVipDto superVipDto = new SuperVipDto();
        if (superVip == null) {
            superVipDto.setVipFlag(0);
        } else {
            SuperVipPo endTime = vipMapper.findEndTime(userId);
            if (endTime == null) {
                superVipDto.setVipFlag(-1);
                superVipDto.setEndTime(superVip.getEndTime());
            } else {
                superVipDto.setVipFlag(1);
                superVipDto.setEndTime(superVip.getEndTime());
            }
        }
        return superVipDto;
    }

    @Override
    public ResponseJson<Integer> getByUserId(Integer userType, Integer id) {
        return ResponseJson.success(baseMapper.getByUserId(userType, id));
    }
}
